Learn R Programming

ROC632 (version 0.5)

ROC632-package: Estimation of prognostic capacity of microarray data.

Description

This package can be used for proposing prognostic scoring systems based on few explanatories variables or based on thousand features from microarray. The methodology is adapted to complete data (penalized logistic regression associated with ROC curve) incomplete time-to-event data (penalized Cox model associated with ROC time-dependent ROC curve).

Arguments

Details

ll{ Package: ROC632 Type: Package Version: 0.5 Date: 2013-26-12 License: GPL (>=2) LazyLoad: yes } rl{ ROC This function allows to compute traditional ROC curves (complete data) for $\mbox{ }$ a binary outcome and a continuous marker. AUC This function computes the area under ROC curve using the trapezoidal rule $\mbox{ }$ based on two vectors of sensitivities and specificities. boot.ROC This function allows the construction of a prognostic or $\mbox{ }$ a diagnostic signature (complete data) by using bootstrap-based algorithms $\mbox{ }$ for correcting the overfitting. boot.ROCt This function allows the construction of a prognostic $\mbox{ }$ signature (time-to-event data) by using bootstrap-based algorithms $\mbox{ }$ for correcting the overfitting. }

References

R. Danger and Y. Foucher. Time dependent ROC curves for the estimation of true prognostic capacity of microarray data. Statistical Applications in Genetics and Molecular Biology. 2012 Nov 22;11(6):Article 1.

See Also

URL: http://www.divat.fr